==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/MULTIEQUIPSPLITINFO.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;choice>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}RELATEDWORKORDERID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}SPLITTOOPENONLY"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "relatedworkorderid",
    "splittoopenonly"
})
@XmlRootElement(name = "MULTIEQUIPSPLITINFO")
public class MULTIEQUIPSPLITINFO {

    @XmlElement(name = "RELATEDWORKORDERID")
    protected WOID_Type relatedworkorderid;
    @XmlElement(name = "SPLITTOOPENONLY")
    protected String splittoopenonly;

    /**
     * Obtient la valeur de la propriété relatedworkorderid.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getRELATEDWORKORDERID() {
        return relatedworkorderid;
    }

    /**
     * Définit la valeur de la propriété relatedworkorderid.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setRELATEDWORKORDERID(WOID_Type value) {
        this.relatedworkorderid = value;
    }

    /**
     * Obtient la valeur de la propriété splittoopenonly.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSPLITTOOPENONLY() {
        return splittoopenonly;
    }

    /**
     * Définit la valeur de la propriété splittoopenonly.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSPLITTOOPENONLY(String value) {
        this.splittoopenonly = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/MULTIEQUIPSPLITINFO.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;choice>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}RELATEDWORKORDERID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}SPLITTOOPENONLY"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "relatedworkorderid",
    "splittoopenonly"
})
@XmlRootElement(name = "MULTIEQUIPSPLITINFO")
public class MULTIEQUIPSPLITINFO {

    @XmlElement(name = "RELATEDWORKORDERID")
    protected WOID_Type relatedworkorderid;
    @XmlElement(name = "SPLITTOOPENONLY")
    protected String splittoopenonly;

    /**
     * Gets the value of the relatedworkorderid property.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getRELATEDWORKORDERID() {
        return relatedworkorderid;
    }

    /**
     * Sets the value of the relatedworkorderid property.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setRELATEDWORKORDERID(WOID_Type value) {
        this.relatedworkorderid = value;
    }

    /**
     * Gets the value of the splittoopenonly property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSPLITTOOPENONLY() {
        return splittoopenonly;
    }

    /**
     * Sets the value of the splittoopenonly property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSPLITTOOPENONLY(String value) {
        this.splittoopenonly = value;
    }

}
